@@ -30,8 +30,7 @@ func Test_RegoScanning_Deny(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -78,8 +77,7 @@ func Test_RegoScanning_AbsolutePolicyPath_Deny(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -123,8 +121,7 @@ func Test_RegoScanning_Allow(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -171,8 +168,7 @@ func Test_RegoScanning_WithRuntimeValues(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -215,8 +211,7 @@ func Test_RegoScanning_WithDenyMessage(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -263,8 +258,7 @@ func Test_RegoScanning_WithDenyMetadata_ImpliedPath(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -318,8 +312,7 @@ func Test_RegoScanning_WithDenyMetadata_PersistedPath(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -371,7 +364,6 @@ package defsec.test
 
 __rego_metadata__ := {
 	"id": "AA001",
-	"avd_id": "AVD-XX-9999",
 	"title": "This is a title",
 	"short_code": "short-code",
 	"severity": "LOW",
@@ -416,8 +408,7 @@ deny[res] {
 	assert.Equal(t, "/blah.txt", failure.Metadata().Range().GetFilename())
 	assert.Equal(t, 123, failure.Metadata().Range().GetStartLine())
 	assert.Equal(t, 456, failure.Metadata().Range().GetEndLine())
-	assert.Equal(t, "AVD-XX-9999", failure.Rule().AVDID)
-	assert.True(t, failure.Rule().HasID("AA001"))
+	assert.Equal(t, "AA001", failure.Rule().ID)
 	assert.Equal(t, "This is a title", failure.Rule().Summary)
 	assert.Equal(t, severity.Low, failure.Rule().Severity)
 	assert.Equal(t, "This is a recommendation", failure.Rule().Resolution)
@@ -434,8 +425,7 @@ func Test_RegoScanning_WithMatchingInputSelector(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -516,8 +506,7 @@ func Test_RegoScanning_NoTracingByDefault(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -562,8 +551,7 @@ func Test_RegoScanning_GlobalTracingEnabled(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -612,8 +600,7 @@ func Test_RegoScanning_PerResultTracingEnabled(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -722,7 +709,6 @@ func Test_annotationMetadata(t *testing.T) {
 # - https://google.com
 # custom:
 #   id: EG123
-#   avd_id: AVD-EG-0123
 #   severity: LOW
 #   recommended_action: have a cup of tea
 package defsec.test
@@ -762,7 +748,6 @@ deny {
 	assert.Equal(t, "i am a description", failure.Explanation)
 	require.Len(t, failure.Links, 1)
 	assert.Equal(t, "https://google.com", failure.Links[0])
-	assert.Equal(t, "AVD-EG-0123", failure.AVDID)
 	assert.Equal(t, severity.Low, failure.Severity)
 	assert.Equal(t, "have a cup of tea", failure.Resolution)
 }
@@ -841,8 +826,7 @@ func Test_RegoScanning_CustomData(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -894,8 +878,7 @@ func Test_RegoScanning_InvalidFS(t *testing.T) {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -974,7 +957,6 @@ func Test_RegoScanning_WithDeprecatedCheck(t *testing.T) {
 # - https://google.com
 # custom:
 #   id: EG123
-#   avd_id: AVD-EG-0123
 #   severity: LOW
 #   recommended_action: have a cup of tea
 #   deprecated: %v
