@@ -32,7 +32,7 @@ func Test_OptionWithPolicyDirs(t *testing.T) {
 	require.Len(t, results.GetFailed(), 1)
 
 	failure := results.GetFailed()[0]
-	assert.Equal(t, "USER-TEST-0123", failure.Rule().AVDID)
+	assert.Equal(t, "USER-TEST-0123", failure.Rule().ID)
 
 	actualCode, err := failure.GetCode()
 	require.NoError(t, err)
@@ -189,7 +189,6 @@ resource "aws_sqs_queue_policy" "bad_example" {
 # - https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-using-identity-based-policies.html
 # custom:
 #   id: TEST123
-#   avd_id: AVD-TEST-0123
 #   short_code: no-wildcard-actions
 #   severity: CRITICAL
 #   recommended_action: Avoid using "*" for actions in SQS policies and specify only required actions.
@@ -223,9 +222,8 @@ deny[res] {
 	require.NoError(t, err)
 
 	require.Len(t, results.GetFailed(), 1)
-	assert.Equal(t, "AVD-TEST-0123", results[0].Rule().AVDID)
+	assert.Equal(t, "TEST123", results[0].Rule().ID)
 	assert.NotNil(t, results[0].Metadata().Range().GetFS())
-
 }
 
 func Test_ContainerDefinitionRego(t *testing.T) {
@@ -273,8 +271,7 @@ package defsec.abcdefg
 
 
 __rego_metadata__ := {
-	"id": "TEST123",
-	"avd_id": "AVD-TEST-0123",
+	"id": "TEST-0123",
 	"title": "Buckets should not be evil",
 	"short_code": "no-evil-buckets",
 	"severity": "CRITICAL",
@@ -306,7 +303,7 @@ deny[res] {
 	require.NoError(t, err)
 
 	require.Len(t, results.GetFailed(), 1)
-	assert.Equal(t, "AVD-TEST-0123", results[0].Rule().AVDID)
+	assert.Equal(t, "TEST-0123", results[0].Rule().ID)
 	assert.NotNil(t, results[0].Metadata().Range().GetFS())
 
 }
@@ -361,13 +358,13 @@ resource "aws_s3_bucket_public_access_block" "foo" {
 	failed := results.GetFailed()
 	for _, result := range failed {
 		// public access block
-		assert.NotEqual(t, "AVD-AWS-0094", result.Rule().AVDID, "AVD-AWS-0094 should not be reported - was found at "+result.Metadata().Range().String())
+		assert.NotEqual(t, "AVD-AWS-0094", result.Rule().ID, "AVD-AWS-0094 should not be reported - was found at "+result.Metadata().Range().String())
 		// encryption
-		assert.NotEqual(t, "AVD-AWS-0088", result.Rule().AVDID)
+		assert.NotEqual(t, "AVD-AWS-0088", result.Rule().ID)
 		// logging
-		assert.NotEqual(t, "AVD-AWS-0089", result.Rule().AVDID)
+		assert.NotEqual(t, "AVD-AWS-0089", result.Rule().ID)
 		// versioning
-		assert.NotEqual(t, "AVD-AWS-0090", result.Rule().AVDID)
+		assert.NotEqual(t, "AVD-AWS-0090", result.Rule().ID)
 	}
 }
 
@@ -423,7 +420,7 @@ resource "aws_s3_bucket_public_access_block" "testB" {
 
 	for _, result := range results.GetFailed() {
 		// public access block
-		assert.NotEqual(t, "AVD-AWS-0094", result.Rule().AVDID)
+		assert.NotEqual(t, "AVD-AWS-0094", result.Rule().ID)
 	}
 
 }
@@ -442,7 +439,7 @@ resource "aws_apigatewayv2_stage" "bad_example" {
 # schemas:
 # - input: schema.input
 # custom:
-#   avd_id: AVD-AWS-0001
+#   id: AWS-0001
 #   input:
 #     selector:
 #     - type: cloud
@@ -481,7 +478,7 @@ deny[res] {
 
 	failure := results.GetFailed()[0]
 
-	assert.Equal(t, "AVD-AWS-0001", failure.Rule().AVDID)
+	assert.Equal(t, "AWS-0001", failure.Rule().ID)
 
 	actualCode, err := failure.GetCode()
 	require.NoError(t, err)
@@ -636,7 +633,7 @@ resource "aws_security_group" "main" {
 # schemas:
 # - input: schema.input
 # custom:
-#   avd_id: AVD-AWS-0002
+#   id: AWS-0002
 #   input:
 #     selector:
 #     - type: cloud
@@ -666,7 +663,7 @@ deny[res] {
 
 	assert.Len(t, results.GetPassed(), 2)
 	require.Len(t, results.GetFailed(), 1)
-	assert.Equal(t, "AVD-AWS-0002", results.GetFailed()[0].Rule().AVDID)
+	assert.Equal(t, "AWS-0002", results.GetFailed()[0].Rule().ID)
 }
 
 func Test_RoleRefToOutput(t *testing.T) {
@@ -706,7 +703,7 @@ output "role_name" {
 # schemas:
 # - input: schema.input
 # custom:
-#   avd_id: AVD-AWS-0001
+#   id: AWS-0001
 #   input:
 #     selector:
 #     - type: cloud
@@ -755,7 +752,7 @@ provider "aws" {
 # schemas:
 # - input: schema.input
 # custom:
-#   avd_id: AVD-AWS-0001
+#   id: AWS-0001
 #   input:
 #     selector:
 #     - type: cloud
@@ -774,7 +771,7 @@ deny[res] {
 # schemas:
 # - input: schema.input
 # custom:
-#   avd_id: AVD-AWS-0002
+#   id: AWS-0002
 #   input:
 #     selector:
 #     - type: cloud
@@ -804,10 +801,10 @@ deny[res] {
 	require.Len(t, results, 2)
 
 	require.Len(t, results.GetFailed(), 1)
-	assert.Equal(t, "AVD-AWS-0001", results.GetFailed()[0].Rule().AVDID)
+	assert.Equal(t, "AWS-0001", results.GetFailed()[0].Rule().ID)
 
 	require.Len(t, results.GetPassed(), 1)
-	assert.Equal(t, "AVD-AWS-0002", results.GetPassed()[0].Rule().AVDID)
+	assert.Equal(t, "AWS-0002", results.GetPassed()[0].Rule().ID)
 }
 
 func TestScanModuleWithCount(t *testing.T) {
@@ -837,7 +834,7 @@ module "this" {
 # schemas:
 # - input: schema.input
 # custom:
-#   avd_id: AVD-AWS-0001
+#   id: AWS-0001
 #   input:
 #     selector:
 #     - type: cloud
@@ -979,8 +976,7 @@ resource "aws_s3_bucket_versioning" "test" {
 # schemas:
 #   - input: schema["input"]
 # custom:
-#   id: AVD-BAR-0001
-#   avd_id: AVD-BAR-0001
+#   id: BAR-0001
 #   provider: custom
 #   service: custom
 #   severity: LOW
@@ -1014,8 +1010,7 @@ func TestRenderedCause(t *testing.T) {
 	s3check := `# METADATA
 # title: S3 Data should be versioned
 # custom:
-#   id: AVD-AWS-0090
-#   avd_id: AVD-AWS-0090
+#   id: AWS-0090
 package user.aws.s3.aws0090
 
 import rego.v1
@@ -1032,8 +1027,7 @@ deny contains res if {
 	iamcheck := `# METADATA
 # title: Service accounts should not have roles assigned with excessive privileges
 # custom:
-#   id: AVD-GCP-0007
-#   avd_id: AVD-GCP-0007
+#   id: GCP-0007
 package user.google.iam.google0007
 
 import rego.v1
